// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef FCITXQT5WIDGETSADDONS_VERSION_H
#define FCITXQT5WIDGETSADDONS_VERSION_H

#define FCITXQT5WIDGETSADDONS_VERSION_STRING "1.1.0"
#define FCITXQT5WIDGETSADDONS_VERSION_MAJOR 1
#define FCITXQT5WIDGETSADDONS_VERSION_MINOR 1
#define FCITXQT5WIDGETSADDONS_VERSION_PATCH 0
#define FCITXQT5WIDGETSADDONS_VERSION ((1<<16)|(1<<8)|(0))

#endif
